.. _2026-name:

!!!!
2026
!!!!

.. meta::
   :keywords: 2026,xrst,release,notes,for,mm-dd,01-04

.. index:: 2026, xrst, release, notes, 2026

.. _2026-title:

xrst Release Notes for 2026
###########################

.. contents::
   :local:

.. index:: mm-dd

.. _2026@mm-dd:

mm-dd
*****

.. _2026@mm-dd@01-04:

01-04
=====
In the ``bin/version.sh`` development tool,
correct the automatic editing of yyyymmdd.r version numbers.
In the ``bin/new_release.sh`` development tool,
if the local or remove version of the stable branch does not yet exist,
print message suggesting it be created.
